@@ -21,7 +21,7 @@
 from . import invocation
 from . import verification
 
-from .utils import get_function_host
+from .utils import get_obj, get_obj_attr_tuple
 from .mocking import Mock
 from .mock_registry import mock_registry
 from .verification import VerificationError
@@ -110,6 +110,9 @@ def verify(obj, times=1, atleast=None, atmost=None, between=None,
 
     """
 
+    if isinstance(obj, str):
+        obj = get_obj(obj)
+
     verification_fn = _get_wanted_verification(
         times=times, atleast=atleast, atmost=atmost, between=between)
     if inorder:
@@ -197,6 +200,10 @@ def when(obj, strict=None):
     See related :func:`when2` which has a more pythonic interface.
 
     """
+
+    if isinstance(obj, str):
+        obj = get_obj(obj)
+
     if strict is None:
         strict = True
     theMock = _get_mock(obj, strict=strict)
@@ -227,26 +234,40 @@ def when2(fn, *args, **kwargs):
         statement.
 
     """
-    obj, name = get_function_host(fn)
+    obj, name = get_obj_attr_tuple(fn)
     theMock = _get_mock(obj, strict=True)
     return invocation.StubbedInvocation(theMock, name)(*args, **kwargs)
 
 
-def patch(fn, new_fn):
-    """Patch/Replace given function.
+def patch(fn, attr_or_replacement, replacement=None):
+    """Patch/Replace a function.
 
-    Note that after that all interactions will be recorded and can be verified.
+    This is really like monkeypatching, but *note* that all interactions
+    will be recorded and can be verified. That is, using `patch` you stay in
+    the domain of mockito.
 
-    ::
+    Two ways to call this. Either::
 
-        with patch(os.path.exists, lambda str: True):
-            ...
+        patch(os.path.exists, lambda str: True)  # two arguments
+        # OR
+        patch(os.path, 'exists', lambda str: True)  # three arguments
+
+    If called with three arguments, the mode is *not* strict to allow *adding*
+    methods. If called with two arguments, mode is always `strict`.
 
     .. note:: You must :func:`unstub` after stubbing, or use `with`
         statement.
 
     """
-    when2(fn, Ellipsis).thenAnswer(new_fn)
+    if replacement is None:
+        replacement = attr_or_replacement
+        when2(fn, Ellipsis).thenAnswer(replacement)
+    else:
+        obj, name = fn, attr_or_replacement
+        theMock = _get_mock(obj, strict=True)
+        return invocation.StubbedInvocation(
+            theMock, name, strict=False)(Ellipsis).thenAnswer(replacement)
+
 
 
 def expect(obj, strict=None,
